"""mems.lib.persistent_list

Provides the PersistentList class, an analogue to ZODB's
PersistentMapping that ZODB forgot.  Hopefully this module will go away
someday, to be replaced by ZODB.PersistentList.
"""

# created 2000/09/11, GPW (from code by AMK in mxtoy/python/util.py)

__revision__ = "$Id: PersistentList.py,v 1.1 2000/11/11 12:31:47 amk Exp $"

import UserList
from Persistence import Persistent

class PersistentList(Persistent, UserList.UserList):
    "Wrapper class for lists that sets ._p_changed correctly"
    def __setitem__(self, i, item):
        self._p_changed = 1
        self.data[i] = item

    def __delitem__(self, i):
        self._p_changed = 1
        del self.data[i]

    def __setslice__(self, i, j, other):
        self._p_changed = 1
        i = max(i, 0); j = max(j, 0)
        if isinstance(other, UserList):
            self.data[i:j] = other.data
        elif isinstance(other, type(self.data)):
            self.data[i:j] = other
        else:
            self.data[i:j] = list(other)

    def __delslice__(self, i, j):
        self._p_changed = 1
        i = max(i, 0); j = max(j, 0)
        del self.data[i:j]

    def append(self, item):
        self._p_changed = 1
        self.data.append(item)

    def insert(self, i, item):
        self._p_changed = 1
        self.data.insert(i, item)

    def pop(self, i=-1):
        self._p_changed = 1
        return self.data.pop(i)

    def remove(self, item):
        self._p_changed = 1
        self.data.remove(item)

    def reverse(self):
        self._p_changed = 1
        self.data.reverse()

    def sort(self, *args):
        self._p_changed = 1
        apply(self.data.sort, args)

    def extend(self, other):
        self._p_changed = 1
        if isinstance(other, UserList.UserList):
            self.data.extend(other.data)
        else:
            self.data.extend(other)

    def __repr__(self):
        return '<%s at %s: %s>' % (self.__class__.__name__,
                                   hex(id(self)), repr(self.data))


# class PersistentList

