#!/usr/bin/env python

# Setup file for ZODB package
# Python modules written by Digital Creations <http://www.digicool.com>
# setup.py written by A.M. Kuchling <amk1@bigfoot.com>

from distutils.core import setup
from distutils.extension import Extension

# Set the include directory for ExtensionClass; if this script is
# being executed directly, assume ExtensionClass has already
# been installed

if __name__ == '__main__':
    include_dirs = []
else:
    include_dirs = ['..']

# XXX which of these extension modules really need to be installed?
# For now they'll all get installed.

cPersistence = Extension(name = 'ZODB.cPersistence',
                         include_dirs = include_dirs,
                         sources= ['cPersistence.c']
                         )
cPickleCache = Extension(name = 'ZODB.cPickleCache',
                         include_dirs = include_dirs,
                         sources= ['cPickleCache.c']
                         )
TimeStamp = Extension(name = 'ZODB.TimeStamp',
                      define_macros = [('USE_EXTENSION_CLASS', 1)],
                      include_dirs = include_dirs,
                      sources= ['TimeStamp.c']
                      )
coptimizations = Extension(name = 'ZODB.coptimizations',
                           include_dirs = include_dirs,
                           sources= ['coptimizations.c']
                           )
winlock = Extension(name = 'ZODB.winlock',
                    include_dirs = include_dirs,
                    sources = ['winlock.c'])

setup(name = "ZODB", 
      version = "2.3.2",
      description = "Z Object Database persistence system",
      author = "Digital Creations",
      author_email = "zope-zeo@zope.org",
      url = "http://www.zope.org",

      packages=['ZODB', 'ZODB.test'],
      package_dir = {'ZODB':'.'},
      
      ext_modules = [cPersistence, cPickleCache, TimeStamp,
                     coptimizations, winlock],
      headers = ["cPersistence.h"]
      )

